Description: <h2>Yamaha YDP-S52 B Digitalpiano</h2> <p>&nbsp;</p> <div> <ul> <li>88 Tasten</li> <li>Graded Hammer (GH) Tastatur</li> <li>Anschlagdynamik: Hard, Medium, Soft, Fixed</li> <li>Pedale: 3 (D&auml;mpfer, Sostenuto, Soft) mit Halbpedal</li> <li>Tonerz
Keywords: Musikhaus,Lörrach,Basel,Rheinfelden,Schopfheim, WeilGitarre,Ukulele,Taylor,Fender,Lakewood,E-Piano

Musik Dreiklang
Suche:

Willkommen bei Musik Dreiklang, das Fachgeschäft für Musiker in Lörrach

- Mein Benutzerkonto
- Anmelden

# Yamaha YDP-S52 B Digitalpiano

E-Mail an einen Freund

Schreiben Sie die erste Kundenmeinung

Verfügbarkeit: sofort lieferbar

999,00 €
Barpreis inkl 19%Mwst

- | Auf die Vergleichsliste

##

# Produktvideo YDP-S51

Klicken Sie doppelt auf das obere Bild, um es im voller Größe zu sehen

## Mehr Ansichten

## Details

## Yamaha YDP-S52 B Digitalpiano

- 88 Tasten
- Graded Hammer (GH) Tastatur
- Anschlagdynamik: Hard, Medium, Soft, Fixed
- Pedale: 3 (Dämpfer, Sostenuto, Soft) mit Halbpedal
- Tonerzeugung: Pure CF Sound Engine
- max. Polyphonie: 192 Stimmen
- Preset Voices: 10
- Effekte: 4 Reverbs, Intelligent Acoustic Control (IAC), Stereophonic Optimizer, Dämpferresonanz
- Funktionen: Dual/Layers, Duo
- Preset Songs: 50
- Aufnahme-Funktion: 1 Song/2 Spuren (100 KB pro Song/ca. 11000 Noten)
- Demo Songs: 10
- Overall-Controls: Metronom, Tempobereich (5 - 280), Transpose (-6 bis 0, 0 bis +6), Tuning
- Anschlüsse: 2 x Kopfhörer, USB to Host
- Verstärker: 2 x 20 W
- Lautsprecher: 2 x (12 x 6 cm)
- Acoustic Optimizer
- Netzteil: PA-300C oder entsprechende Netzteile
- Auto Power OFF
- Bediensprache: Englisch
- Tastaturabdeckung
- Notenablage
- Abmessungen (B x H x T): 1353 x 792 x 309 mm
- Gewicht: 37,8 kg